@@ -20,17 +20,34 @@ class MagicianGoApi(object):
                                                         r=r)
 
     def set_rotate_deg_speed(self, port_name, r, Vr):
-        return self.__dobotlink.MagicianGO.SetMoveDistance(portName=port_name,
-                                                           r=r,
-                                                           Vr=Vr)
+        return self.__dobotlink.MagicianGO.SetMoveDistance(
+            portName=port_name,
+            r=r,
+            Vr=Vr,
+            isQueued=True,
+            isWaitForFinish=True,
+            timeout=604800000)
 
     def set_xy_speed_distance(self, port_name, x, y, Vx, Vy):
         return self.__dobotlink.MagicianGO.SetFixedOrientationMoveDistance(
-            portName=port_name, x=x, y=y, Vx=Vx, Vy=Vy)
+            portName=port_name,
+            x=x,
+            y=y,
+            Vx=Vx,
+            Vy=Vy,
+            isQueued=True,
+            isWaitForFinish=True,
+            timeout=604800000)
 
     def moveto_destination(self, port_name, x, y, s):
         return self.__dobotlink.MagicianGO.SetWorldCoordinateMovePoint(
-            portName=port_name, x=x, y=y, s=s)
+            portName=port_name,
+            x=x,
+            y=y,
+            s=s,
+            isQueued=True,
+            isWaitForFinish=True,
+            timeout=604800000)
 
     def move_radius_arc(self, port_name, velocity, radius, angle, mode):
         return self.__dobotlink.MagicianGO.SetTraceRadiusARC(
@@ -38,7 +55,10 @@ class MagicianGoApi(object):
             velocity=velocity,
             radius=radius,
             angle=angle,
-            mode=mode)
+            mode=mode,
+            isQueued=True,
+            isWaitForFinish=True,
+            timeout=604800000)
 
     def move_circular_arc(self, port_name, velocity, x, y, angle, mode):
         return self.__dobotlink.MagicianGO.SetTraceCenterARC(
@@ -47,7 +67,10 @@ class MagicianGoApi(object):
             x=x,
             y=y,
             angle=angle,
-            mode=mode)
+            mode=mode,
+            isQueued=True,
+            isWaitForFinish=True,
+            timeout=604800000)
 
     def set_coord_closed_loop(self, port_name, isEnable, angle):
         return self.__dobotlink.MagicianGO.SetCoordClosedLoop(
@@ -55,7 +78,13 @@ class MagicianGoApi(object):
 
     def set_increment_closed_loop(self, port_name, x, y, angle):
         return self.__dobotlink.MagicianGO.SetIncrementClosedLoop(
-            portName=port_name, x=x, y=y, angle=angle)
+            portName=port_name,
+            x=x,
+            y=y,
+            angle=angle,
+            isQueued=True,
+            isWaitForFinish=True,
+            timeout=604800000)
 
     def set_rgb_light(self, port_name, number, effect, r, g, b, cycle, counts):
         return self.__dobotlink.MagicianGO.SetLightRGB(portName=port_name,
@@ -108,14 +137,26 @@ class MagicianGoApi(object):
 
 # k210
 
-    def get_k210_angle(self, port_name):
+    def get_lite_angle(self, port_name):
         return self.__dobotlink.MagicianGO.GetK210ArmAngleData(
             portName=port_name)
 
-    def get_k210_deeplearning(self, port_name):
+    def get_car_angle(self, port_name):
+        return self.__dobotlink.MagicianGO.GetK210CarAngleData(
+            portName=port_name)
+
+    def get_lite_deeplearning(self, port_name):
         return self.__dobotlink.MagicianGO.GetK210ArmDeepLearningObj(
             portName=port_name)
 
-    def get_k210_apriltag(self, port_name):
+    def get_car_deeplearning(self, port_name):
+        return self.__dobotlink.MagicianGO.GetK210CarDeepLearningObj(
+            portName=port_name)
+
+    def get_lite_apriltag(self, port_name):
         return self.__dobotlink.MagicianGO.GetK210ArmAprilTag(
             portName=port_name)
+
+    def get_car_apriltag(self, port_name):
+        return self.__dobotlink.MagicianGO.GetK210CarAprilTag(
+            portName=port_name)
